@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #   Mugshot - Lightweight user configuration utility
-#   Copyright (C) 2013-2018 Sean Davis <smd.seandavis@gmail.com>
+#   Copyright (C) 2013-2019 Sean Davis <sean@bluesabre.org>
 #
 #   This program is free software: you can redistribute it and/or modify it
 #   under the terms of the GNU General Public License as published by
@@ -73,7 +73,7 @@ class Window(Gtk.Window):
 
     def on_help_activate(self, widget, data=None):
         """Show the Help documentation when Help is clicked."""
-        show_uri(self, "https://wiki.bluesabre.org/doku.php?id=mugshot-docs")
+        show_uri(self, "https://github.com/bluesabre/mugshot/wiki")
 
     def on_menu_camera_activate(self, widget, data=None):
         """Display the camera window for mugshot."""
